@@ -13,7 +13,7 @@ from . import authenticator
 
 
 class BasketCase:
-    def __init__(self):
+    def __init__(self, force_flag = False):
         # Create application data directory
         self._data_directory = f'{Path.home()!s}/.basketcase'
         Path(self._data_directory).mkdir(parents=True, exist_ok=True)
@@ -27,10 +27,10 @@ class BasketCase:
         self._storage = storage.Storage(self._data_directory)
         self._http_client = requests.Session()
         self.authenticator = authenticator.Authenticator(self._http_client, self._storage)
-        self._extractor = extractor.Extractor(self._http_client)
+        self.extractor = extractor.Extractor(http_client=self._http_client, force=force_flag)
 
     def fetch(self, target_urls):
-        resources = self._extractor.scan(target_urls)
+        resources = self.extractor.scan(target_urls)
 
         if resources['images'] or resources['videos']:
             # Create media output directories
