@@ -2,8 +2,9 @@ import re
 
 
 class Extractor:
-    def __init__(self, http_client):
+    def __init__(self, http_client, force = False):
         self._http_client = http_client
+        self.force = force
 
     def scan(self, target_urls):
         resources = {
@@ -16,13 +17,11 @@ class Extractor:
         for target_url in target_urls:
             media_id = self._get_media_id(target_url)
             profile_id = self._get_profile_id(target_url)
+            highlight_id = self._get_highlight_id(target_url)
 
             if profile_id:
                 media_info = self._get_profile_info(profile_id)
 
-                if 'status' in media_info and media_info['status'] != 'ok':
-                    raise RuntimeError(media_info['message'])
-
                 for reel_id, reel_item in media_info['reels'].items():
                     for item in reel_item['items']:
                         image_url = item['image_versions2']['candidates'][0]['url']
@@ -40,9 +39,6 @@ class Extractor:
             elif media_id:
                 media_info = self._get_media_info(media_id)
 
-                if 'status' in media_info and media_info['status'] != 'ok':
-                    raise RuntimeError(media_info['message'])
-
                 for item in media_info['items']:
                     if 'carousel_media' in item:
                         carousel_items = item['carousel_media']
@@ -73,7 +69,24 @@ class Extractor:
                             video_url = item['video_versions'][0]['url']
 
                             resources['videos'].add(video_url)
-            else:
+            elif highlight_id:
+                media_info = self._get_highlight_info(highlight_id)
+                
+                for reel_id, reel_item in media_info['reels'].items():
+                    for item in reel_item['items']:
+                        image_url = item['image_versions2']['candidates'][0]['url']
+                        image_id = item['id']
+
+                        resources['images'][image_url] = {
+                            'url': image_url,
+                            'id': image_id
+                        }
+
+                        if 'video_versions' in item:
+                            video_url = item['video_versions'][0]['url']
+
+                            resources['videos'].add(video_url)
+            elif not self.force:
                 raise RuntimeError(f'Failed to recognize resource type: {target_url}')
 
         return resources
@@ -116,4 +129,24 @@ class Extractor:
             }
         )
 
+        return response.json()
+    
+    def _get_highlight_id(self, url):
+        response = self._http_client.get(url, timeout=10)
+        highlight_id = re.search(r'"highlight_reel_id"\s*:\s*"(.*?)"', response.text)
+
+        if not highlight_id:
+            return None
+        
+        return highlight_id.group(1)
+
+    def _get_highlight_info(self, highlight_id):
+        response = self._http_client.get(
+            f'https://www.instagram.com/api/v1/feed/reels_media/?reel_ids=highlight:{highlight_id}',
+            timeout=10,
+            headers={
+                'x-ig-app-id': '936619743392459'
+            }
+        )
+
         return response.json()
\ No newline at end of file
